[evolution-activesync] Less 'Exchange' in user visible strings
- From: Milan Crha <mcrha src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [evolution-activesync] Less 'Exchange' in user visible strings
- Date: Tue, 22 May 2012 09:06:28 +0000 (UTC)
commit e8dacbea63e67239e151fc8ecd427a206800f4df
Author: Milan Crha <mcrha redhat com>
Date: Tue May 22 11:05:50 2012 +0200
Less 'Exchange' in user visible strings
QtActivesyncdConfig/ConfigWizard.cpp | 4 +-
camel/camel-eas-provider.c | 6 ++--
camel/camel-eas-store.c | 8 +++---
camel/camel-eas-transport.c | 4 +-
eas-daemon/libeas/eas-connection.c | 6 ++--
eplugin/Makefile.am | 22 +++++++++---------
eplugin/activesync-account-setup.c | 24 ++++++++++----------
...ml => org-gnome-evolution-activesync.eplug.xml} | 20 ++++++++--------
...ml => org-gnome-evolution-activesync.error.xml} | 2 +-
po/POTFILES.in | 2 +-
10 files changed, 49 insertions(+), 49 deletions(-)
---
diff --git a/QtActivesyncdConfig/ConfigWizard.cpp b/QtActivesyncdConfig/ConfigWizard.cpp
index 5ccaf82..64f0a14 100644
--- a/QtActivesyncdConfig/ConfigWizard.cpp
+++ b/QtActivesyncdConfig/ConfigWizard.cpp
@@ -285,7 +285,7 @@ void ConfigWizard::changeState(ConfigWizard::State state)
{
case AutoDiscoverDetails:
ui->wizard->setCurrentWidget(ui->pageAutoConfig);
- setTitle(tr("Automatic configuration"), tr("Enter your e-mail adress and we'll try to guess your Exchange server details."));
+ setTitle(tr("Automatic configuration"), tr("Enter your e-mail adress and we'll try to guess your ActiveSync server details."));
validateAutoDiscoverInputs();
break;
@@ -308,7 +308,7 @@ void ConfigWizard::changeState(ConfigWizard::State state)
case ManualServerDetails:
serverDetailsEnteredManually = true;
ui->wizard->setCurrentWidget(ui->pageManualConfig);
- setTitle(tr("Manual configuration"), tr("Sorry, your Exchange server details could not be guessed. Please enter them below."));
+ setTitle(tr("Manual configuration"), tr("Sorry, your ActiveSync server details could not be guessed. Please enter them below."));
validateManualServerInputs();
break;
diff --git a/camel/camel-eas-provider.c b/camel/camel-eas-provider.c
index ffdfaa2..a40c989 100644
--- a/camel/camel-eas-provider.c
+++ b/camel/camel-eas-provider.c
@@ -66,9 +66,9 @@ static CamelProviderConfEntry eas_conf_entries[] = {
static CamelProvider eas_provider = {
"eas",
- N_("Exchange ActiveSync"),
+ N_("ActiveSync"),
- N_("For accessing Exchange servers using ActiveSync"),
+ N_("For accessing servers using ActiveSync"),
"mail",
@@ -86,7 +86,7 @@ static CamelProvider eas_provider = {
CamelServiceAuthType camel_eas_password_authtype = {
N_("Password"),
- N_("This option will connect to the Exchange server using a "
+ N_("This option will connect to the ActiveSync server using a "
"plaintext password."),
"",
diff --git a/camel/camel-eas-store.c b/camel/camel-eas-store.c
index e118589..36e67e2 100644
--- a/camel/camel-eas-store.c
+++ b/camel/camel-eas-store.c
@@ -490,10 +490,10 @@ eas_get_name (CamelService *service, gboolean brief)
CamelURL *url = camel_service_get_camel_url (service);
if (brief)
- return g_strdup_printf(_("Exchange ActiveSync server %s"),
+ return g_strdup_printf(_("ActiveSync server %s"),
url->host);
else
- return g_strdup_printf(_("Exchange ActiveSync service for %s on %s"),
+ return g_strdup_printf(_("ActiveSync service for %s on %s"),
url->user, url->host);
#else
CamelStoreSettings *settings = CAMEL_STORE_SETTINGS (camel_service_get_settings (service));
@@ -504,10 +504,10 @@ eas_get_name (CamelService *service, gboolean brief)
strings = g_strsplit (account_uid, "@", 0);
if (brief)
- ret = g_strdup_printf(_("Exchange ActiveSync server %s"),
+ ret = g_strdup_printf(_("ActiveSync server %s"),
strings[1]);
else
- ret = g_strdup_printf(_("Exchange ActiveSync service for %s on %s"),
+ ret = g_strdup_printf(_("ActiveSync service for %s on %s"),
strings[0], strings[1]);
g_strfreev (strings);
diff --git a/camel/camel-eas-transport.c b/camel/camel-eas-transport.c
index 6e26977..d2b28d8 100644
--- a/camel/camel-eas-transport.c
+++ b/camel/camel-eas-transport.c
@@ -69,10 +69,10 @@ eas_transport_get_name (CamelService *service,
if (brief)
return g_strdup_printf (
- _("Exchange server %s"), host);
+ _("ActiveSync server %s"), host);
else
return g_strdup_printf (
- _("Exchange mail delivery via %s"), host);
+ _("ActiveSync mail delivery via %s"), host);
}
static gboolean
diff --git a/eplugin/Makefile.am b/eplugin/Makefile.am
index 7c31eec..5af9a0d 100644
--- a/eplugin/Makefile.am
+++ b/eplugin/Makefile.am
@@ -15,11 +15,11 @@
### EVO_PLUGIN_RULE ### end ###
-plugin_DATA = org-gnome-exchange-activesync.eplug
-plugin_LTLIBRARIES = liborg-gnome-exchange-activesync.la
-#noinst_LTLIBRARIES = liborg-gnome-exchange-activesync.la
+plugin_DATA = org-gnome-evolution-activesync.eplug
+plugin_LTLIBRARIES = liborg-gnome-evolution-activesync.la
+#noinst_LTLIBRARIES = liborg-gnome-evolution-activesync.la
-liborg_gnome_exchange_activesync_la_CPPFLAGS = \
+liborg_gnome_evolution_activesync_la_CPPFLAGS = \
$(AM_CPPFLAGS) \
$(EVOLUTION_DATA_SERVER_CFLAGS) \
$(EVOLUTION_PLUGIN_CFLAGS) \
@@ -31,12 +31,12 @@ liborg_gnome_exchange_activesync_la_CPPFLAGS = \
-liborg_gnome_exchange_activesync_la_SOURCES = \
+liborg_gnome_evolution_activesync_la_SOURCES = \
activesync-account-setup.c \
eas-account-listener.c \
eas-account-listener.h
-liborg_gnome_exchange_activesync_la_LIBADD = \
+liborg_gnome_evolution_activesync_la_LIBADD = \
$(top_builddir)/libeasclient/libeasclient.la \
$(top_builddir)/libevoeas/libevoeas.la \
$(EVOLUTION_DATA_SERVER_LIBS) \
@@ -47,17 +47,17 @@ liborg_gnome_exchange_activesync_la_LIBADD = \
$(SYNCEVOLUTION_DBUS_LIBS) \
$(DNS_LIBS)
-liborg_gnome_exchange_activesync_la_LDFLAGS = \
+liborg_gnome_evolution_activesync_la_LDFLAGS = \
-module -avoid-version $(NO_UNDEFINED)
-error_DATA = org-gnome-exchange-activesync.error
+error_DATA = org-gnome-evolution-activesync.error
errordir = $(EVOLUTION_PLUGIN_errordir)
EXTRA_DIST = \
- org-gnome-exchange-activesync.eplug.xml \
- org-gnome-exchange-activesync.error.xml
+ org-gnome-evolution-activesync.eplug.xml \
+ org-gnome-evolution-activesync.error.xml
-BUILT_SOURCES = $(error_DATA) org-gnome-exchange-activesync.eplug
+BUILT_SOURCES = $(error_DATA) org-gnome-evolution-activesync.eplug
CLEANFILES = $(BUILT_SOURCES)
diff --git a/eplugin/org-gnome-exchange-activesync.eplug.xml b/eplugin/org-gnome-evolution-activesync.eplug.xml
similarity index 55%
rename from eplugin/org-gnome-exchange-activesync.eplug.xml
rename to eplugin/org-gnome-evolution-activesync.eplug.xml
index a046519..645c30e 100644
--- a/eplugin/org-gnome-exchange-activesync.eplug.xml
+++ b/eplugin/org-gnome-evolution-activesync.eplug.xml
@@ -2,25 +2,25 @@
<e-plugin-list>
<e-plugin
type="shlib"
- id="org.gnome.evolution.plugin.exchange-activesync"
- location="@PLUGINDIR@/liborg-gnome-exchange-activesync SOEXT@"
+ id="org.gnome.evolution.plugin.activesync"
+ location="@PLUGINDIR@/liborg-gnome-evolution-activesync SOEXT@"
load-on-startup="true"
- _name="Exchange ActiveSync"
+ _name="ActiveSync"
system_plugin="true">
<author name="Srinivasa Ragavan" email="sragavan gnome org"/>
- <_description>Exchange Activesync plugin for Evolution.</_description>
+ <_description>ActiveSync plugin for Evolution.</_description>
<hook class="org.gnome.evolution.mail.config:1.0">
- <group target="settings" id="org.gnome.evolution.mail.config.accountEditor" check="org_gnome_exchange_check_options" commit="org_gnome_exchange_commit">
- <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_exchange_server_url"/>
+ <group target="settings" id="org.gnome.evolution.mail.config.accountEditor" check="org_gnome_activesync_check_options" commit="org_gnome_activesync_commit">
+ <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_activesync_server_url"/>
</group>
- <group target="settings" id="org.gnome.evolution.mail.config.accountAssistant" check="org_gnome_exchange_check_options">
- <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_exchange_server_url"/>
+ <group target="settings" id="org.gnome.evolution.mail.config.accountAssistant" check="org_gnome_activesync_check_options">
+ <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_activesync_server_url"/>
</group>
- <group target="settings" id="org.gnome.evolution.mail.config.accountWizard" check="org_gnome_exchange_check_options">
- <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_exchange_server_url"/>
+ <group target="settings" id="org.gnome.evolution.mail.config.accountWizard" check="org_gnome_activesync_check_options">
+ <item type="item_table" path="10.receive/10.config/20.eas" factory="org_gnome_activesync_server_url"/>
</group>
</hook>
diff --git a/eplugin/org-gnome-exchange-activesync.error.xml b/eplugin/org-gnome-evolution-activesync.error.xml
similarity index 50%
rename from eplugin/org-gnome-exchange-activesync.error.xml
rename to eplugin/org-gnome-evolution-activesync.error.xml
index 03fc1c1..013cdfe 100644
--- a/eplugin/org-gnome-exchange-activesync.error.xml
+++ b/eplugin/org-gnome-evolution-activesync.error.xml
@@ -1,4 +1,4 @@
<?xml version="1.0" encoding="UTF-8"?>
-<error-list domain="org-gnome-exchange-activesync">
+<error-list domain="org-gnome-evolution-activesync">
</error-list>
diff --git a/po/POTFILES.in b/po/POTFILES.in
index ca3772c..4f1bd47 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -10,4 +10,4 @@ eas-daemon/libeas/eas-connection.c
eas-daemon/libeas/eas-connection.c
eplugin/activesync-account-setup.c
eplugin/eas-account-listener.c
-eplugin/org-gnome-exchange-activesync.eplug.xml
+eplugin/org-gnome-evolution-activesync.eplug.xml
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/eas-daemon/libeas/eas-connection.c b/eas-daemon/libeas/eas-connection.c
index 015e7c4..5eb0469 100644
--- a/eas-daemon/libeas/eas-connection.c
+++ b/eas-daemon/libeas/eas-connection.c
@@ -393,7 +393,7 @@ static gboolean
mainloop_password_store (gpointer data)
{
EasGnomeKeyringResponse *response = data;
- gchar * description = g_strdup_printf ("Exchange Server Password for %s %s",
+ gchar * description = g_strdup_printf ("ActiveSync Server Password for %s %s",
response->username,
response->serverUri);
@@ -1002,7 +1002,7 @@ eas_active_job_dequeue (EasConnection *cnc, EasNode *eas_node)
/**
* WBXML encode the message and send to exchange server via libsoup.
* May also be required to temporarily hold the request message whilst
* provisioning with the server occurs.
*
@@ -1332,7 +1332,7 @@ isResponseValid (SoupMessage *msg, gboolean multipart, GError **error)
/**
* Converts from Microsoft Exchange Server protocol WBXML to XML
* @param wbxml input buffer
* @param wbxml_len input buffer length
* @param xml output buffer [full transfer]
@@ -1002,7 +1002,7 @@ eas_active_job_dequeue (EasConnection *cnc, EasNode *eas_node)
/**
- * WBXML encode the message and send to exchange server via libsoup.
+ * WBXML encode the message and send to activesync server via libsoup.
* May also be required to temporarily hold the request message whilst
* provisioning with the server occurs.
@@ -1332,7 +1332,7 @@ isResponseValid (SoupMessage *msg, gboolean multipart, GError **error)
/**
- * Converts from Microsoft Exchange Server protocol WBXML to XML
+ * Converts from Microsoft ActiveSync Server protocol WBXML to XML
* @param wbxml input buffer
* @param wbxml_len input buffer length
diff --git a/eplugin/activesync-account-setup.c b/eplugin/activesync-account-setup.c
index d263f06..11431b6 100644
--- a/eplugin/activesync-account-setup.c
+++ b/eplugin/activesync-account-setup.c
@@ -54,12 +54,12 @@
static EasAccountListener *config_listener = NULL;
-GtkWidget *org_gnome_exchange_server_url(EPlugin *epl, EConfigHookItemFactoryData *data);
-gboolean org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data);
+GtkWidget *org_gnome_activesync_server_url(EPlugin *epl, EConfigHookItemFactoryData *data);
+gboolean org_gnome_activesync_check_options(EPlugin *epl, EConfigHookPageCheckData *data);
#if EDS_CHECK_VERSION (3,3,90)
-void org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetSettings *target_account);
+void org_gnome_activesync_commit (EPlugin *epl, EMConfigTargetSettings *target_account);
#else
-void org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account);
+void org_gnome_activesync_commit (EPlugin *epl, EMConfigTargetAccount *target_account);
#endif
#define EVOLUTION_ACCOUNT_URL_FORMAT "eas://%s/;account_uid=%s;passwd_exp_warn_period=7;ad_limit=500;check_all;owa_url=%s"
@@ -309,7 +309,7 @@ discover_server_url (GtkWidget *button, EConfig *config)
#if EDS_CHECK_VERSION(3,3,90)
GtkWidget *
-org_gnome_exchange_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
+org_gnome_activesync_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
{
EMConfigTargetSettings *target_account;
const gchar *source_url;
@@ -414,7 +414,7 @@ org_gnome_exchange_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
#else
/* used by editor and assistant - same code */
GtkWidget *
-org_gnome_exchange_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
+org_gnome_activesync_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
{
EMConfigTargetAccount *target_account;
const gchar *source_url;
@@ -536,7 +536,7 @@ org_gnome_exchange_server_url(EPlugin *epl, EConfigHookItemFactoryData *data)
#if EDS_CHECK_VERSION (3,3,90)
gboolean
-org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
+org_gnome_activesync_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
{
EMConfigTargetSettings *target = (EMConfigTargetSettings *)(data->config->target);
CamelEasSettings *eas_settings;
@@ -560,7 +560,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
g_object_unref (client);
g_free (key);
/* Note: we only care about exchange url's, we WILL get called on all other url's too. */
if ((!url|| !*url)
&& strcmp(target->storage_protocol, "eas") == 0) {
status = FALSE;
@@ -574,7 +574,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
#else
gboolean
-org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
+org_gnome_activesync_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
{
EMConfigTargetAccount *target = (EMConfigTargetAccount *)data->config->target;
gint status = TRUE;
@@ -600,7 +600,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
g_object_unref (client);
g_free (key);
/* Note: we only care about exchange url's, we WILL get called on all other url's too. */
if ((!url|| !*url)
&& strcmp(curl->protocol, "eas") == 0) {
status = FALSE;
@@ -615,7 +615,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
#if EDS_CHECK_VERSION (3,3,90)
void
-org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetSettings *target_account)
+org_gnome_activesync_commit (EPlugin *epl, EMConfigTargetSettings *target_account)
{
if (!CAMEL_IS_EAS_SETTINGS (target_account->storage_settings))
return;
@@ -628,7 +628,7 @@ org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetSettings *target_account)
}
#else
void
-org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account)
+org_gnome_activesync_commit (EPlugin *epl, EMConfigTargetAccount *target_account)
{
const gchar *source_url;
CamelURL *url;
@@ -560,7 +560,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
g_object_unref (client);
g_free (key);
- /* Note: we only care about exchange url's, we WILL get called on all other url's too. */
+ /* Note: we only care about activesync url's, we WILL get called on all other url's too. */
if ((!url|| !*url)
&& strcmp(target->storage_protocol, "eas") == 0) {
@@ -600,7 +600,7 @@ org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data)
g_object_unref (client);
g_free (key);
- /* Note: we only care about exchange url's, we WILL get called on all other url's too. */
+ /* Note: we only care about activesync url's, we WILL get called on all other url's too. */
if ((!url|| !*url)
&& strcmp(curl->protocol, "eas") == 0) {